@@ -28,7 +28,7 @@ class MegaFlow2D(Dataset):
         self.transforms = transform
         self.pre_transform = pre_transform
         if download:
-            self.download(root)
+            self.download()
         self.raw_data_dir = os.path.join(self.root, 'raw')
         self.processed_data_dir = os.path.join(self.root, 'processed')
         self.data_list = self.processed_file_names
@@ -79,9 +79,9 @@ class MegaFlow2D(Dataset):
     def len(self):
         return len(self.data_list)
 
-    def download(self, dir=None):
+    def download(self):
         url = 'https://huggingface.co/datasets/cmudrc/MegaFlow2D/resolve/main/data.zip'
-        path = download_url(url, dir)
+        path = download_url(url, self.root)
         extract_zip(path, self.root)
 
     def process(self):
